@@ -88,7 +88,5 @@ class Workspace(object):
 
         if event:
             return event
-
-        self.logger.error('Event Key %s is not defined.' % event_key)
-
-        return None
+        else:
+            return entities.Event(0, event_key)
